<!--
Please do not ask general questions here! There are [community
contact](https://github.com/qtile/qtile#community) options for that.

If you are suggesting a new feature/enhancement please instead post it on the
discussions board as an idea: https://github.com/qtile/qtile/discussions/categories/ideas
-->

# Issue description

<!--
A brief discussion of what failed and how it failed. A description of
what you tried is helpful, i.e. "When I use lazy.kill() on a window I get
the following stack trace" instead of "Closing windows doesn't work".
-->

# Qtile version

<!--
Please include the exact commit hash of the version of Qtile that failed.
-->

# Stack traces

<!--
Please attach any stack traces found in:

* `~/.xsession-errors`
* `~/.local/share/qtile/qtile.log`
-->

# Configuration

<!--
Please include a link or attach your configuration to the issue.
-->
